<?php
/** Megleno-Romanian (Vlăheşte)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 * @comment falls back to Megleno-Romanian (Latin)
 *
 */

$fallback = 'ruq-latn, ro';
